#ifndef NT2_INCLUDE_CONSTANTS_INVSQRT_2PI_HPP_INCLUDED
#define NT2_INCLUDE_CONSTANTS_INVSQRT_2PI_HPP_INCLUDED

#include <nt2/trigonometric/include/constants/invsqrt_2pi.hpp>

#endif
